@@ -4,7 +4,7 @@ from upytl import html as h, Component
 meta_data = {
     'data-web23py': '{web23py}',
     'data-app_root': '{app_root}',
-    'data-app_static': '{app_static}'
+    'data-app_static': {'URL("static")'},
 }
 
 
